@@ -38,6 +38,14 @@ else
     exit 1
 fi
 
+# components, with optional '=VERSION'
+COMPONENTS=(
+'docker/libnetwork'
+'docker/distribution'
+'docker/swarmkit'
+"containerd/containerd=v$( cat debian/helpers/containerd-version )"
+)
+
 export XZ_OPT="-6v"
 DEB_SOURCE="$( dpkg-parsechangelog -SSource )"
 #DEB_VERSION="$( dpkg-parsechangelog -SVersion )"
@@ -103,15 +111,22 @@ drop_files_excluded "${work_dir}"/*/components/*
 tarpack "${work_dir}" "${filename}"
 
 ## fetch Docker components:
-for I in docker/go-events docker/libnetwork docker/distribution docker/swarmkit containerd/containerd; do
+for I in "${COMPONENTS[@]}"; do
     printf ":: Processing ${I}\n" 1>&2
-    URL="github.com/${I}"
-    REV=$( grep "${URL}" "${work_dir}"/*/engine/vendor.conf | head -1 | awk '{print $2}' )
+
+    C=$(   echo ${I} | awk -F= '{print $1}' )
+    REV=$( echo ${I} | awk -F= '{print $2}' )
+    URL="github.com/${C}"
+
+    if [ -z "$REV" ]; then
+	# get revision from engine/vendor.conf
+        REV=$( grep "${URL}" "${work_dir}"/*/engine/vendor.conf | head -1 | awk '{print $2}' )
+    fi
     if [ -z "${REV}" ]; then
-        printf "E: could not find commit for ${I}\n" 1>&2
+        printf "E: could not find commit for ${C}\n" 1>&2
         exit 1
     fi
-    component=${I##*/}
+    component=${C##*/}
     FN="$( readlink -f ../${DEB_SOURCE}_${version}.orig-${component}.tar.gz )"
 
     if [ ! -s "${FN}" ]; then
