@@ -7,6 +7,9 @@ DOCKER=docker
 IMAGE_TAG=${IMAGE_TAG:-debian/sid/docker-builder}
 ACNG_PORT=${ACNG_PORT:-3142}
 
+CMD=${1:-}
+shift
+
 
 ## misc helpers
 
@@ -47,7 +50,8 @@ docker_run_as_user() {
 	  -v /etc/passwd:/etc/passwd:ro \
 	  -v $(pwd)/..:/usr/src/ \
 	  -w /usr/src/$(basename $(pwd)) \
-	  $IMAGE_TAG
+	  $IMAGE_TAG \
+	  "$@"
 }
 
 docker_run_as_root() {
@@ -55,7 +59,8 @@ docker_run_as_root() {
 	  --privileged \
 	  -v $(pwd)/..:/usr/src \
 	  -w /usr/src/$(basename $(pwd)) \
-	  $IMAGE_TAG
+	  $IMAGE_TAG \
+	  "$@"
 }
 
 
@@ -67,13 +72,14 @@ test -d debian || \
 user_in_docker_group || \
 	DOCKER='sudo docker'
 
-case ${1:-} in
+
+case "$CMD" in
 	(build)
 		docker_build ;;
 	(run-user)
-		docker_run_as_user ;;
+		docker_run_as_user "$@" ;;
 	(run-root)
-		docker_run_as_root ;;
+		docker_run_as_root "$@" ;;
 	(*)
-		fail "Usage: $(basename $0) build|run-user|run-root" ;;
+		fail "Usage: $(basename $0) build | run-user [CMD] | run-root [CMD]" ;;
 esac
